@@ -35,6 +35,8 @@ class LanzouDirectory(BaseTable):
                 "isfile": 0
             }
             self.insert(values=data)
+            if _dir.name.endswith(".tar"):
+                continue
             self._scan_all_file(fid=data['fid'], path=data['path'])
 
         for _file in self.drive.get_file_list(fid):
