@@ -162,8 +162,8 @@ class DataFileProperty:
         return True
 
     def _load(self, start_end_fun, total=100):
-        # for i in range(1,total):
-        for i in range(total, 0, -1):
+        for i in range(1, total):
+            # for i in range(total, 0, -1):
             try:
                 self.file_pro.start_date, self.file_pro.end_date = start_end_fun(-i)
                 self._daily_load_and_save(self.file_pro)
